@@ -31,6 +31,8 @@ import (
 	"knative.dev/pkg/reconciler"
 )
 
+const conflictReason = "DomainConflict"
+
 type Reconciler struct {
 	xdsServer         *envoy.XdsServer
 	caches            *generator.Caches
@@ -52,13 +54,13 @@ func (r *Reconciler) ReconcileKind(ctx context.Context, ing *v1alpha1.Ingress) r
 		// If we had an error due to a duplicated domain, we must mark the ingress as failed with a
 		// custom status. We don't want to return an error in this case as we want to update its status.
 		logging.FromContext(ctx).Info(err.Error())
-		ing.Status.MarkLoadBalancerFailed("DomainConflict", "Ingress rejected: "+err.Error())
+		ing.Status.MarkLoadBalancerFailed(conflictReason, "Ingress rejected: "+err.Error())
 		return nil
 	} else if err != nil {
 		return fmt.Errorf("failed to update ingress: %w", err)
 	}
 
-	if !ing.IsReady() {
+	if !ing.IsReady() || !isExpectedLoadBalancer(ing) {
 		ready, err := r.statusManager.IsReady(ctx, before)
 		if err != nil {
 			return fmt.Errorf("failed to probe Ingress: %w", err)
@@ -78,6 +80,20 @@ func (r *Reconciler) ReconcileKind(ctx context.Context, ing *v1alpha1.Ingress) r
 	return nil
 }
 
+// isExpectedLoadBalancer verifies if expected Loadbalancer is set in status field.
+func isExpectedLoadBalancer(ing *v1alpha1.Ingress) bool {
+	external, internal := config.ServiceHostnames()
+	if ing.Status.PublicLoadBalancer == nil || len(ing.Status.PublicLoadBalancer.Ingress) < 1 ||
+		ing.Status.PublicLoadBalancer.Ingress[0].DomainInternal != external {
+		return false
+	}
+	if ing.Status.PrivateLoadBalancer == nil || len(ing.Status.PrivateLoadBalancer.Ingress) < 1 ||
+		ing.Status.PrivateLoadBalancer.Ingress[0].DomainInternal != internal {
+		return false
+	}
+	return true
+}
+
 func (r *Reconciler) ObserveKind(ctx context.Context, ing *v1alpha1.Ingress) reconciler.Event {
 	ing.SetDefaults(ctx)
 
